from rich.console import Console
from rich.highlighter import JSONHighlighter
from rich.style import Style
from rich.text import Span

from partial_json_parser import ALL, PartialJSON, complete_any

console = Console()
highlight = JSONHighlighter()


def main():
    while True:
        try:
            input_str = console.input("[d]>>> ")
            result = complete_any(input_str, ALL, is_top_level=True)
            if result is False:
                raise PartialJSON
            index, completion = result
            json = input_str if completion is True else input_str[:index] + completion

            rich_text = highlight(json)
            if completion is not True and completion:
                rich_text.spans.append(Span(index, len(json), Style(dim=True)))

            console.print(" " * 3, rich_text)

        except KeyboardInterrupt:
            return
        except Exception as err:
            console.print(f"{err.__class__.__name__}:", style="bold red", highlight=False, end=" ")
            console.print(" ".join(map(str, err.args)), style="yellow", highlight=False)
